# Copyright © 2022 Arrikto Inc.  All Rights Reserved.

"""This script defines a custom transformer."""

import kserve
from typing import Dict
import argparse


class Transformer(kserve.Model):
    """Define custom transformer."""

    def __init__(self, model_name: str, predictor_host: str, protocol: str):
        super().__init__(model_name)
        self.predictor_host = predictor_host
        self.protocol = protocol

    def preprocess(self, request: Dict):
        return request

    def postprocess(self, request: Dict) -> Dict:
        value = request["outputs"][0]["data"][0]
        request["outputs"][0]["data"][0] = round(value * 100000, 2)
        return request


DEFAULT_MODEL_NAME = "custom-model"
DEFAULT_PROTOCOL = "v1"

parser = argparse.ArgumentParser(parents=[kserve.model_server])
parser.add_argument('--model_name', default=DEFAULT_MODEL_NAME,
                    help='The name that the model is served under.')
parser.add_argument('--predictor_host',
                    help='The URL for the model predict function',
                    required=True)
parser.add_argument('--protocol', default=DEFAULT_PROTOCOL,
                    help='The predictor protocol version',
                    required=True)

args, _ = parser.parse_known_args()


if __name__ == "__main__":
    server = kserve.ModelServer()
    model = Transformer(model_name=args.model_name,
                        predictor_host=args.predictor_host,
                        protocol=args.protocol)
    server.start(models=[model])
